@@ -53,8 +53,11 @@ class Request(_Request):
     @property
     def decoded_data(self):
         if self.content_encoding == 'gzip':
-            zipfile = gzip.GzipFile(fileobj=BytesIO(self.data), mode='rb')
-            return zipfile.read()
+            if self.user_id:
+                zipfile = gzip.GzipFile(fileobj=BytesIO(self.data), mode='rb')
+                return zipfile.read()
+            else:
+                abort(HTTPStatus.UNSUPPORTED_MEDIA_TYPE)
         else:
             return self.data
 
@@ -212,6 +215,7 @@ def with_transaction(readonly=None, user=0, context=None):
                     except backend.DatabaseOperationalError:
                         if count and not readonly_:
                             transaction.rollback()
+                            transaction.tasks.clear()
                             continue
                         logger.error('%s', request, exc_info=True)
                         raise
